import cv2
import numpy as np

def carregar_imagem(caminho):
    return cv2.imread(caminho)

def salvar_imagem(caminho, imagem):
    cv2.imwrite(caminho, imagem)

def converter_para_cinza(imagem):
    return cv2.cvtColor(imagem, cv2.COLOR_BGR2GRAY)

def redimensionar(imagem, largura, altura):
    return cv2.resize(imagem, (largura, altura))

def detectar_bordas(imagem):
    imagem_cinza = converter_para_cinza(imagem)
    return cv2.Canny(imagem_cinza, 50, 150)



from suzano_image import processor

def test_redimensionar():
    img = processor.carregar_imagem("tests/exemplo.jpg")
    img_redim = processor.redimensionar(img, 100, 100)
    assert img_redim.shape[0] == 100
    assert img_redim.shape[1] == 100



from setuptools import setup, find_packages

setup(
    name='suzano_image',
    version='0.1',
    packages=find_packages(),
    install_requires=[
        'opencv-python',
        'numpy'
    ],
    author='Seu Nome',
    description='Pacote de processamento de imagens do Bootcamp da Suzano',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
)
